@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2004 Zope Corporation and Contributors.
+# Copyright (c) 2004 Zope Foundation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -12,16 +12,12 @@
 #
 ##############################################################################
 """Evolve the ZODB from Zope 3.1 to a Zope 3.2 compatible format.
-
-$Id: evolve2.py 116577 2010-09-18 12:11:54Z icemac $
 """
 __docformat__ = "reStructuredText"
 
 from zope.app.authentication.principalfolder import IInternalPrincipal
 from zope.app.component.interfaces import ISite
-from zope.app.zopeappgenerations import getRootFolder
-
-from zope.generations.utility import findObjectsProviding
+from zope.generations.utility import findObjectsProviding, getRootFolder
 
 
 generation = 2
